@@ -21,17 +21,18 @@
  *
  */
 
-#include "config.h"
+#include <config.h>
 
-#include <stdlib.h>
 #include <stdio.h>
-
+#include <stdlib.h>
 #include <string.h>
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 
 #include <glib-object.h>
+
 #include <garcon/garcon.h>
 
 #include "gs-theme-manager.h"
@@ -41,16 +42,14 @@ static void     gs_theme_manager_class_init (GSThemeManagerClass *klass);
 static void     gs_theme_manager_init       (GSThemeManager      *theme_manager);
 static void     gs_theme_manager_finalize   (GObject             *object);
 
-struct _GSThemeInfo
-{
+struct _GSThemeInfo {
     char  *name;
     char  *exec;
     char  *file_id;
     guint  refcount;
 };
 
-struct GSThemeManagerPrivate
-{
+struct GSThemeManagerPrivate {
     GarconMenu *menu;
 };
 
@@ -58,53 +57,44 @@ G_DEFINE_TYPE_WITH_PRIVATE (GSThemeManager, gs_theme_manager, G_TYPE_OBJECT)
 
 static gpointer theme_manager_object = NULL;
 
-static const char *known_engine_locations [] =
-{
+static const char *known_engine_locations[] = {
     SAVERDIR,
 #ifdef XSCREENSAVER_HACK_DIR
     XSCREENSAVER_HACK_DIR,
 #endif
     LIBEXECDIR "/xscreensaver",
     LIBDIR "/xscreensaver",
-    NULL
-};
+    "/usr/libexec/xscreensaver",
+    "/usr/lib/xscreensaver",
+    NULL};
 
 /* Returns the full path to the queried command */
 static char *
-find_command (const char *command)
-{
+find_command (const char *command) {
     int i;
 
-    if (g_path_is_absolute (command))
-    {
+    if (g_path_is_absolute (command)) {
         char *dirname;
 
         dirname = g_path_get_dirname (command);
-        for (i = 0; known_engine_locations [i]; i++)
-        {
-            if (strcmp (dirname, known_engine_locations [i]) == 0)
-            {
+        for (i = 0; known_engine_locations[i]; i++) {
+            if (strcmp (dirname, known_engine_locations[i]) == 0) {
                 if (g_file_test (command, G_FILE_TEST_IS_EXECUTABLE)
-                        && ! g_file_test (command, G_FILE_TEST_IS_DIR))
-                {
+                        && !g_file_test (command, G_FILE_TEST_IS_DIR)) {
                     g_free (dirname);
                     return g_strdup (command);
                 }
             }
         }
         g_free (dirname);
-    }
-    else
-    {
-        for (i = 0; known_engine_locations [i]; i++)
-        {
+    } else {
+        for (i = 0; known_engine_locations[i]; i++) {
             char *path;
 
-            path = g_build_filename (known_engine_locations [i], command, NULL);
+            path = g_build_filename (known_engine_locations[i], command, NULL);
 
             if (g_file_test (path, G_FILE_TEST_IS_EXECUTABLE)
-                    && ! g_file_test (path, G_FILE_TEST_IS_DIR))
-            {
+                    && !g_file_test (path, G_FILE_TEST_IS_DIR)) {
                 return path;
             }
 
@@ -116,19 +106,17 @@ find_command (const char *command)
 }
 
 static gboolean
-check_command (const char *command)
-{
+check_command (const char *command) {
     char *path;
     char **argv;
 
     g_return_val_if_fail (command != NULL, FALSE);
 
     g_shell_parse_argv (command, NULL, &argv, NULL);
-    path = find_command (argv [0]);
+    path = find_command (argv[0]);
     g_strfreev (argv);
 
-    if (path != NULL)
-    {
+    if (path != NULL) {
         g_free (path);
         return TRUE;
     }
@@ -137,15 +125,13 @@ check_command (const char *command)
 }
 
 static void
-add_known_engine_locations_to_path (void)
-{
+add_known_engine_locations_to_path (void) {
     static gboolean already_added;
     int      i;
     GString *str;
 
     /* We only want to add the items to the path once */
-    if (already_added)
-    {
+    if (already_added) {
         return;
     }
 
@@ -154,12 +140,10 @@ add_known_engine_locations_to_path (void)
     /* TODO: set a default PATH ? */
 
     str = g_string_new (g_getenv ("PATH"));
-    for (i = 0; known_engine_locations [i]; i++)
-    {
+    for (i = 0; known_engine_locations[i]; i++) {
         /* TODO: check that permissions are safe */
-        if (g_file_test (known_engine_locations [i], G_FILE_TEST_IS_DIR))
-        {
-            g_string_append_printf (str, ":%s", known_engine_locations [i]);
+        if (g_file_test (known_engine_locations[i], G_FILE_TEST_IS_DIR)) {
+            g_string_append_printf (str, ":%s", known_engine_locations[i]);
         }
     }
 
@@ -168,8 +152,7 @@ add_known_engine_locations_to_path (void)
 }
 
 GSThemeInfo *
-gs_theme_info_ref (GSThemeInfo *info)
-{
+gs_theme_info_ref (GSThemeInfo *info) {
     g_return_val_if_fail (info != NULL, NULL);
     g_return_val_if_fail (info->refcount > 0, NULL);
 
@@ -179,13 +162,11 @@ gs_theme_info_ref (GSThemeInfo *info)
 }
 
 void
-gs_theme_info_unref (GSThemeInfo *info)
-{
+gs_theme_info_unref (GSThemeInfo *info) {
     g_return_if_fail (info != NULL);
     g_return_if_fail (info->refcount > 0);
 
-    if (--info->refcount == 0)
-    {
+    if (--info->refcount == 0) {
         g_free (info->name);
         g_free (info->exec);
         g_free (info->file_id);
@@ -195,34 +176,28 @@ gs_theme_info_unref (GSThemeInfo *info)
 }
 
 const char *
-gs_theme_info_get_id (GSThemeInfo *info)
-{
+gs_theme_info_get_id (GSThemeInfo *info) {
     g_return_val_if_fail (info != NULL, NULL);
 
     return info->file_id;
 }
 
 const char *
-gs_theme_info_get_name (GSThemeInfo *info)
-{
+gs_theme_info_get_name (GSThemeInfo *info) {
     g_return_val_if_fail (info != NULL, NULL);
 
     return info->name;
 }
 
 const char *
-gs_theme_info_get_exec (GSThemeInfo *info)
-{
+gs_theme_info_get_exec (GSThemeInfo *info) {
     const char *exec;
 
     g_return_val_if_fail (info != NULL, NULL);
 
-    if (check_command (info->exec))
-    {
+    if (check_command (info->exec)) {
         exec = info->exec;
-    }
-    else
-    {
+    } else {
         exec = NULL;
     }
 
@@ -230,8 +205,7 @@ gs_theme_info_get_exec (GSThemeInfo *info)
 }
 
 static GSThemeInfo *
-gs_theme_info_new_from_garcon_menu_item(GarconMenuItem *item)
-{
+gs_theme_info_new_from_garcon_menu_item(GarconMenuItem *item) {
     GSThemeInfo *info;
     const char     *str;
     char           *pos;
@@ -245,12 +219,9 @@ gs_theme_info_new_from_garcon_menu_item(GarconMenuItem *item)
     /* remove the .desktop suffix */
     str = garcon_menu_item_get_desktop_id (item);
     pos = g_strrstr (str, ".desktop");
-    if (pos)
-    {
+    if (pos) {
         info->file_id = g_strndup (str, pos - str);
-    }
-    else
-    {
+    } else {
         info->file_id  = g_strdup (str);
     }
 
@@ -259,8 +230,7 @@ gs_theme_info_new_from_garcon_menu_item(GarconMenuItem *item)
 
 static GSThemeInfo *
 find_info_for_id (GarconMenu *menu,
-                  const char *id)
-{
+                  const char *id) {
     GSThemeInfo *info;
     GList       *items;
     GList       *l;
@@ -269,16 +239,13 @@ find_info_for_id (GarconMenu *menu,
 
     info = NULL;
 
-    for (l = items; l; l = l->next)
-    {
-        if (info == NULL)
-        {
+    for (l = items; l; l = l->next) {
+        if (info == NULL) {
             GarconMenuItem *item = l->data;
             const char     *file_id;
 
             file_id = garcon_menu_item_get_desktop_id (item);
-            if (file_id && id && strcmp (file_id, id) == 0)
-            {
+            if (file_id && id && strcmp (file_id, id) == 0) {
                 info = gs_theme_info_new_from_garcon_menu_item (item);
             }
         }
@@ -291,8 +258,7 @@ find_info_for_id (GarconMenu *menu,
 
 GSThemeInfo *
 gs_theme_manager_lookup_theme_info (GSThemeManager *theme_manager,
-                                    const char     *name)
-{
+                                    const char     *name) {
     GSThemeInfo *info;
     char        *id;
 
@@ -308,8 +274,7 @@ gs_theme_manager_lookup_theme_info (GSThemeManager *theme_manager,
 
 static void
 theme_prepend_item (GSList         **parent_list,
-                    GarconMenuItem  *item)
-{
+                    GarconMenuItem  *item) {
     GSThemeInfo *info;
 
     info = gs_theme_info_new_from_garcon_menu_item (item);
@@ -319,15 +284,13 @@ theme_prepend_item (GSList         **parent_list,
 
 static void
 make_theme_list (GSList     **parent_list,
-                 GarconMenu  *menu)
-{
+                 GarconMenu  *menu) {
     GList *items;
     GList *l;
 
     items = garcon_menu_get_items (menu);
 
-    for (l = items; l; l = l->next)
-    {
+    for (l = items; l; l = l->next) {
         theme_prepend_item (parent_list, l->data);
     }
 
@@ -337,8 +300,7 @@ make_theme_list (GSList     **parent_list,
 }
 
 GSList *
-gs_theme_manager_get_info_list (GSThemeManager *theme_manager)
-{
+gs_theme_manager_get_info_list (GSThemeManager *theme_manager) {
     GSList             *l = NULL;
 
     g_return_val_if_fail (GS_IS_THEME_MANAGER (theme_manager), NULL);
@@ -349,16 +311,14 @@ gs_theme_manager_get_info_list (GSThemeManager *theme_manager)
 }
 
 static void
-gs_theme_manager_class_init (GSThemeManagerClass *klass)
-{
+gs_theme_manager_class_init (GSThemeManagerClass *klass) {
     GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
     object_class->finalize = gs_theme_manager_finalize;
 }
 
 static GarconMenu *
-get_themes_menu (void)
-{
+get_themes_menu (void) {
     GarconMenu *menu = NULL;
     gchar      *menu_file = g_strconcat(SYSCONFDIR, "/xdg/menus/xfce4-screensavers.menu", NULL);
 
@@ -367,8 +327,7 @@ get_themes_menu (void)
     add_known_engine_locations_to_path ();
 
     menu = garcon_menu_new_for_path (menu_file);
-    if (!garcon_menu_load (menu, NULL, NULL))
-    {
+    if (!garcon_menu_load (menu, NULL, NULL)) {
         g_warning("Failed to load menu.");
     }
 
@@ -376,16 +335,14 @@ get_themes_menu (void)
 }
 
 static void
-gs_theme_manager_init (GSThemeManager *theme_manager)
-{
+gs_theme_manager_init (GSThemeManager *theme_manager) {
     theme_manager->priv = gs_theme_manager_get_instance_private (theme_manager);
 
     theme_manager->priv->menu = get_themes_menu ();
 }
 
 static void
-gs_theme_manager_finalize (GObject *object)
-{
+gs_theme_manager_finalize (GObject *object) {
     GSThemeManager *theme_manager;
 
     g_return_if_fail (object != NULL);
@@ -395,8 +352,7 @@ gs_theme_manager_finalize (GObject *object)
 
     g_return_if_fail (theme_manager->priv != NULL);
 
-    if (theme_manager->priv->menu != NULL)
-    {
+    if (theme_manager->priv->menu != NULL) {
         g_object_unref (G_OBJECT(theme_manager->priv->menu));
     }
 
@@ -404,14 +360,10 @@ gs_theme_manager_finalize (GObject *object)
 }
 
 GSThemeManager *
-gs_theme_manager_new (void)
-{
-    if (theme_manager_object)
-    {
+gs_theme_manager_new (void) {
+    if (theme_manager_object) {
         g_object_ref (theme_manager_object);
-    }
-    else
-    {
+    } else {
         theme_manager_object = g_object_new (GS_TYPE_THEME_MANAGER, NULL);
         g_object_add_weak_pointer (theme_manager_object,
                                    (gpointer *) &theme_manager_object);
