@@ -22,31 +22,29 @@
  *
  */
 
-#include "config.h"
+#include <config.h>
 
+#include <signal.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
-#include <signal.h>
 
-#include <libxfce4util/libxfce4util.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkx.h>
 
-#include "gs-lock-plug.h"
+#include <libxfce4util/libxfce4util.h>
+#include <xfconf/xfconf.h>
 
 #include "gs-auth.h"
-#include "setuid.h"
-
 #include "gs-debug.h"
+#include "gs-lock-plug.h"
+#include "setuid.h"
 #include "xfce4-screensaver-dialog-css.h"
 
-#include <xfconf/xfconf.h>
-
 #define MAX_FAILURES 5
 
 static gboolean verbose = FALSE;
@@ -61,21 +59,30 @@ static char* away_message = NULL;
 static gint monitor_index = 0;
 
 static GOptionEntry entries[] = {
-    {"verbose", 0, 0, G_OPTION_ARG_NONE, &verbose, N_("Show debugging output"), NULL},
-    {"version", 0, 0, G_OPTION_ARG_NONE, &show_version, N_("Version of this application"), NULL},
-    {"enable-logout", 0, 0, G_OPTION_ARG_NONE, &enable_logout, N_("Show the logout button"), NULL},
-    {"logout-command", 0, 0, G_OPTION_ARG_STRING, &logout_command, N_("Command to invoke from the logout button"), NULL},
-    {"enable-switch", 0, 0, G_OPTION_ARG_NONE, &enable_switch, N_("Show the switch user button"), NULL},
-    {"status-message", 0, 0, G_OPTION_ARG_STRING, &status_message, N_("Message to show in the dialog"), N_("MESSAGE")},
-    {"away-message", 0, 0, G_OPTION_ARG_STRING, &away_message, N_("Not used"), N_("MESSAGE")},
-    {"height", 0, 0, G_OPTION_ARG_INT, &dialog_height, N_("Monitor height"), NULL},
-    {"width", 0, 0, G_OPTION_ARG_INT, &dialog_width, N_("Monitor width"), NULL},
-    {"monitor", 0, 0, G_OPTION_ARG_INT, &monitor_index, N_("Monitor index"), NULL},
+    {"verbose", 0, 0, G_OPTION_ARG_NONE, &verbose,
+        N_("Show debugging output"), NULL},
+    {"version", 0, 0, G_OPTION_ARG_NONE, &show_version,
+        N_("Version of this application"), NULL},
+    {"enable-logout", 0, 0, G_OPTION_ARG_NONE, &enable_logout,
+        N_("Show the logout button"), NULL},
+    {"logout-command", 0, 0, G_OPTION_ARG_STRING, &logout_command,
+        N_("Command to invoke from the logout button"), NULL},
+    {"enable-switch", 0, 0, G_OPTION_ARG_NONE, &enable_switch,
+        N_("Show the switch user button"), NULL},
+    {"status-message", 0, 0, G_OPTION_ARG_STRING, &status_message,
+        N_("Message to show in the dialog"), N_("MESSAGE")},
+    {"away-message", 0, 0, G_OPTION_ARG_STRING, &away_message,
+        N_("Not used"), N_("MESSAGE")},
+    {"height", 0, 0, G_OPTION_ARG_INT, &dialog_height,
+        N_("Monitor height"), NULL},
+    {"width", 0, 0, G_OPTION_ARG_INT, &dialog_width,
+        N_("Monitor width"), NULL},
+    {"monitor", 0, 0, G_OPTION_ARG_INT, &monitor_index,
+        N_("Monitor index"), NULL},
     {NULL}
 };
 
-static char* get_id_string(GtkWidget* widget)
-{
+static char* get_id_string(GtkWidget* widget) {
     char* id = NULL;
 
     g_return_val_if_fail(widget != NULL, NULL);
@@ -85,8 +92,7 @@ static char* get_id_string(GtkWidget* widget)
     return id;
 }
 
-static gboolean print_id(GtkWidget* widget)
-{
+static gboolean print_id(GtkWidget* widget) {
     char* id;
 
     gs_profile_start(NULL);
@@ -102,42 +108,36 @@ static gboolean print_id(GtkWidget* widget)
     return FALSE;
 }
 
-static void response_cancel(void)
-{
+static void response_cancel(void) {
     printf("RESPONSE=CANCEL\n");
     fflush(stdout);
 }
 
-static void response_ok(void)
-{
+static void response_ok(void) {
     printf("RESPONSE=OK\n");
     fflush(stdout);
 }
 
-static gboolean quit_response_ok(void)
-{
+static gboolean quit_response_ok(void) {
     response_ok();
     gtk_main_quit();
     return FALSE;
 }
 
-static gboolean quit_response_cancel(void)
-{
+static gboolean quit_response_cancel(void) {
     response_cancel();
     gtk_main_quit();
     return FALSE;
 }
 
-static void response_lock_init_failed(void)
-{
+static void response_lock_init_failed(void) {
     /* if we fail to lock then we should drop the dialog */
     response_ok();
 }
 
 static char* request_response(GSLockPlug* plug,
                               const char* prompt,
-                              gboolean visible)
-{
+                              gboolean visible) {
     int response;
     char* text;
 
@@ -145,12 +145,11 @@ static char* request_response(GSLockPlug* plug,
     gs_lock_plug_enable_prompt(plug, prompt, visible);
     response = gs_lock_plug_run(plug);
 
-    gs_debug ("got response: %d", response);
+    gs_debug ("Got response: %d", response);
 
     text = NULL;
 
-    if (response == GS_LOCK_PLUG_RESPONSE_OK)
-    {
+    if (response == GS_LOCK_PLUG_RESPONSE_OK) {
         gs_lock_plug_get_text(plug, &text);
     }
 
@@ -160,39 +159,55 @@ static char* request_response(GSLockPlug* plug,
 }
 
 /* Adapted from MDM2 daemon/verify-pam.c on 2006-06-13 */
-static const char* maybe_translate_message(const char* msg)
-{
+static const char* maybe_translate_message(const char* msg) {
     char              *s;
     const char        *ret;
     static GHashTable *hash = NULL;
 
-    if (hash == NULL)
-    {
+    if (hash == NULL) {
         /* Here we come with some fairly standard messages so that
            we have as much as possible translated.  Should really be
            translated in pam I suppose.  This way we can "change"
            some of these messages to be more sane. */
         hash = g_hash_table_new (g_str_hash, g_str_equal);
         /* login: is whacked always translate to Username: */
-        g_hash_table_insert(hash, "login:", _("Please enter your username."));
-        g_hash_table_insert(hash, "Username:", _("Please enter your username."));
+        g_hash_table_insert(hash, "login:",
+                            _("Please enter your username."));
+        g_hash_table_insert(hash, "Username:",
+                            _("Please enter your username."));
         g_hash_table_insert(hash, "username:", _("Please enter your username."));
-        g_hash_table_insert(hash, "Password:", "");
-        g_hash_table_insert(hash, "password:", "");
-        g_hash_table_insert(hash, "You are required to change your password immediately (password aged)", _("You are required to change your password immediately (password aged)"));
-        g_hash_table_insert(hash, "You are required to change your password immediately (root enforced)", _("You are required to change your password immediately (root enforced)"));
-        g_hash_table_insert(hash, "Your account has expired; please contact your system administrator", _("Your account has expired; please contact your system administrator"));
-        g_hash_table_insert(hash, "No password supplied", _("No password supplied."));
-        g_hash_table_insert(hash, "Password unchanged", _("Password unchanged."));
-        g_hash_table_insert(hash, "Can not get username", _("Can not get username."));
-        g_hash_table_insert(hash, "Retype new UNIX password:", _("Retype your new password."));
-        g_hash_table_insert(hash, "Enter new UNIX password:", _("Enter your new password."));
-        g_hash_table_insert(hash, "(current) UNIX password:", _("Enter your current password:"));
-        g_hash_table_insert(hash, "Error while changing NIS password.", _("Error while changing NIS password."));
-        g_hash_table_insert(hash, "You must choose a longer password", _("You must choose a longer password."));
-        g_hash_table_insert(hash, "Password has been already used. Choose another.", _("Password has been already used. Choose another."));
-        g_hash_table_insert(hash, "You must wait longer to change your password", _("You must wait longer to change your password."));
-        g_hash_table_insert(hash, "Sorry, passwords do not match", _("Sorry, passwords do not match."));
+        g_hash_table_insert(hash, "Password:",
+                            "");
+        g_hash_table_insert(hash, "password:",
+                            "");
+        g_hash_table_insert(hash, "You are required to change your password immediately (password aged)",
+                            _("You are required to change your password immediately (password aged)"));
+        g_hash_table_insert(hash, "You are required to change your password immediately (root enforced)",
+                            _("You are required to change your password immediately (root enforced)"));
+        g_hash_table_insert(hash, "Your account has expired; please contact your system administrator",
+                            _("Your account has expired; please contact your system administrator"));
+        g_hash_table_insert(hash, "No password supplied",
+                            _("No password supplied."));
+        g_hash_table_insert(hash, "Password unchanged",
+                            _("Password unchanged."));
+        g_hash_table_insert(hash, "Can not get username",
+                            _("Can not get username."));
+        g_hash_table_insert(hash, "Retype new UNIX password:",
+                            _("Retype your new password."));
+        g_hash_table_insert(hash, "Enter new UNIX password:",
+                            _("Enter your new password."));
+        g_hash_table_insert(hash, "(current) UNIX password:",
+                            _("Enter your current password:"));
+        g_hash_table_insert(hash, "Error while changing NIS password.",
+                            _("Error while changing NIS password."));
+        g_hash_table_insert(hash, "You must choose a longer password",
+                            _("You must choose a longer password."));
+        g_hash_table_insert(hash, "Password has been already used. Choose another.",
+                            _("Password has been already used. Choose another."));
+        g_hash_table_insert(hash, "You must wait longer to change your password",
+                            _("You must wait longer to change your password."));
+        g_hash_table_insert(hash, "Sorry, passwords do not match",
+                            _("Sorry, passwords do not match."));
         /* FIXME: what about messages which have some variables in them, perhaps try to do those as well */
     }
 
@@ -200,12 +215,9 @@ static const char* maybe_translate_message(const char* msg)
     ret = g_hash_table_lookup(hash, s);
     g_free(s);
 
-    if (ret != NULL)
-    {
+    if (ret != NULL) {
         return ret;
-    }
-    else
-    {
+    } else {
         return msg;
     }
 }
@@ -213,8 +225,7 @@ static const char* maybe_translate_message(const char* msg)
 static gboolean auth_message_handler(GSAuthMessageStyle   style,
                                      const char          *msg,
                                      char               **response,
-                                     gpointer data)
-{
+                                     gpointer             data) {
     gboolean    ret;
     GSLockPlug *plug;
     const char *message;
@@ -231,19 +242,16 @@ static gboolean auth_message_handler(GSAuthMessageStyle   style,
     *response = NULL;
     message = maybe_translate_message(msg);
 
-    switch (style)
-    {
+    switch (style) {
         case GS_AUTH_MESSAGE_PROMPT_ECHO_ON:
-            if (msg != NULL)
-            {
+            if (msg != NULL) {
                 char *resp;
                 resp = request_response(plug, message, TRUE);
                 *response = resp;
             }
             break;
         case GS_AUTH_MESSAGE_PROMPT_ECHO_OFF:
-            if (msg != NULL)
-            {
+            if (msg != NULL) {
                 char *resp;
                 resp = request_response(plug, message, FALSE);
                 *response = resp;
@@ -259,20 +267,16 @@ static gboolean auth_message_handler(GSAuthMessageStyle   style,
             g_assert_not_reached();
     }
 
-    if (*response == NULL)
-    {
+    if (*response == NULL) {
         gs_debug("Got no response");
         ret = FALSE;
-    }
-    else
-    {
+    } else {
         gs_lock_plug_show_message(plug, _("Checking..."));
         gs_lock_plug_set_sensitive(plug, FALSE);
     }
 
     /* we may have pending events that should be processed before continuing back into PAM */
-    while (gtk_events_pending())
-    {
+    while (gtk_events_pending()) {
         gtk_main_iteration();
     }
 
@@ -282,16 +286,14 @@ static gboolean auth_message_handler(GSAuthMessageStyle   style,
     return ret;
 }
 
-static gboolean reset_idle_cb(GSLockPlug* plug)
-{
+static gboolean reset_idle_cb(GSLockPlug* plug) {
     gs_lock_plug_set_sensitive(plug, TRUE);
     gs_lock_plug_show_message(plug, NULL);
 
     return FALSE;
 }
 
-static gboolean do_auth_check(GSLockPlug* plug)
-{
+static gboolean do_auth_check(GSLockPlug* plug) {
     GError   *error;
     gboolean  res;
 
@@ -303,23 +305,18 @@ static gboolean do_auth_check(GSLockPlug* plug)
 
     gs_debug("Verify user returned: %s", res ? "TRUE" : "FALSE");
 
-    if (! res)
-    {
-        if (error != NULL)
-        {
+    if (!res) {
+        if (error != NULL) {
             gs_debug("Verify user returned error: %s", error->message);
             gs_lock_plug_show_message(plug, error->message);
-        }
-        else
-        {
+        } else {
             gs_lock_plug_show_message(plug, _("Authentication failed."));
         }
 
         printf("NOTICE=AUTH FAILED\n");
         fflush(stdout);
 
-        if (error != NULL)
-        {
+        if (error != NULL) {
             g_error_free(error);
         }
     }
@@ -328,29 +325,24 @@ static gboolean do_auth_check(GSLockPlug* plug)
 }
 
 static void response_cb(GSLockPlug *plug,
-                        gint        response_id)
-{
-    if ((response_id == GS_LOCK_PLUG_RESPONSE_CANCEL) || (response_id == GTK_RESPONSE_DELETE_EVENT))
-    {
+                        gint        response_id) {
+    if ((response_id == GS_LOCK_PLUG_RESPONSE_CANCEL) || (response_id == GTK_RESPONSE_DELETE_EVENT)) {
         quit_response_cancel();
     }
 }
 
-static gboolean response_request_quit(void)
-{
+static gboolean response_request_quit(void) {
     printf("REQUEST QUIT\n");
     fflush(stdout);
     return FALSE;
 }
 
-static gboolean quit_timeout_cb(gpointer data)
-{
+static gboolean quit_timeout_cb(gpointer data) {
     gtk_main_quit();
     return FALSE;
 }
 
-static gboolean auth_check_idle(GSLockPlug* plug)
-{
+static gboolean auth_check_idle(GSLockPlug* plug) {
     gboolean     res;
     gboolean     again;
     static guint loop_counter = 0;
@@ -358,22 +350,16 @@ static gboolean auth_check_idle(GSLockPlug* plug)
     again = TRUE;
     res = do_auth_check(plug);
 
-    if (res)
-    {
+    if (res) {
         again = FALSE;
         g_idle_add((GSourceFunc) quit_response_ok, NULL);
-    }
-    else
-    {
+    } else {
         loop_counter++;
 
-        if (loop_counter < MAX_FAILURES)
-        {
+        if (loop_counter < MAX_FAILURES) {
             gs_debug ("Authentication failed, retrying (%u)", loop_counter);
             g_timeout_add (3000, (GSourceFunc) reset_idle_cb, plug);
-        }
-        else
-        {
+        } else {
             gs_debug ("Authentication failed, quitting (max failures)");
             again = FALSE;
             /* Don't quit immediately, but rather request that xfce4-screensaver
@@ -388,13 +374,11 @@ static gboolean auth_check_idle(GSLockPlug* plug)
 }
 
 static void show_cb(GtkWidget *widget,
-                    gpointer   data)
-{
+                    gpointer   data) {
     print_id(widget);
 }
 
-static gboolean popup_dialog_idle(void)
-{
+static gboolean popup_dialog_idle(void) {
     GtkWidget      *widget;
     GtkCssProvider *css_provider;
 
@@ -402,23 +386,19 @@ static gboolean popup_dialog_idle(void)
 
     widget = gs_lock_plug_new();
 
-    if (enable_logout)
-    {
+    if (enable_logout) {
         g_object_set(widget, "logout-enabled", TRUE, NULL);
     }
 
-    if (logout_command)
-    {
+    if (logout_command) {
         g_object_set(widget, "logout-command", logout_command, NULL);
     }
 
-    if (enable_switch)
-    {
+    if (enable_switch) {
         g_object_set(widget, "switch-enabled", TRUE, NULL);
     }
 
-    if (status_message)
-    {
+    if (status_message) {
         g_object_set(widget, "status-message", status_message, NULL);
     }
 
@@ -430,7 +410,10 @@ static gboolean popup_dialog_idle(void)
     g_signal_connect(widget, "show", G_CALLBACK(show_cb), NULL);
 
     css_provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_data (css_provider, xfce4_screensaver_dialog_css, xfce4_screensaver_dialog_css_length, NULL);
+    gtk_css_provider_load_from_data (css_provider,
+                                     xfce4_screensaver_dialog_css,
+                                     xfce4_screensaver_dialog_css_length,
+                                     NULL);
     gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (css_provider),
                                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
@@ -454,8 +437,7 @@ static gboolean popup_dialog_idle(void)
 */
 static gboolean privileged_initialization(int       *argc,
                                           char     **argv,
-                                          gboolean   verbose)
-{
+                                          gboolean   verbose) {
     gboolean  ret;
     char     *nolock_reason;
     char     *orig_uid;
@@ -470,13 +452,11 @@ static gboolean privileged_initialization(int       *argc,
 
     ret = hack_uid(&nolock_reason, &orig_uid, &uid_message);
 
-    if (nolock_reason)
-    {
+    if (nolock_reason) {
         g_debug("Locking disabled: %s", nolock_reason);
     }
 
-    if (uid_message && verbose)
-    {
+    if (uid_message && verbose) {
         g_print("Modified UID: %s", uid_message);
     }
 
@@ -499,17 +479,14 @@ static gboolean privileged_initialization(int       *argc,
 static gboolean lock_initialization (int       *argc,
                                      char     **argv,
                                      char     **nolock_reason,
-                                     gboolean   verbose)
-{
-    if (nolock_reason != NULL)
-    {
+                                     gboolean   verbose) {
+    if (nolock_reason != NULL) {
         *nolock_reason = NULL;
     }
 
     #ifdef NO_LOCKING
 
-        if (nolock_reason != NULL)
-        {
+        if (nolock_reason != NULL) {
             *nolock_reason = g_strdup("not compiled with locking support");
         }
 
@@ -517,10 +494,8 @@ static gboolean lock_initialization (int       *argc,
     #else /* !NO_LOCKING */
 
         /* Finish initializing locking, now that we're out of privileged code. */
-        if (!gs_auth_init())
-        {
-            if (nolock_reason != NULL)
-            {
+        if (!gs_auth_init()) {
+            if (nolock_reason != NULL) {
                 *nolock_reason = g_strdup("error getting password");
             }
 
@@ -531,10 +506,8 @@ static gboolean lock_initialization (int       *argc,
          * we have been launched as MDM's "Background" program, then disable
          * locking just in case.
          */
-        if (getenv("RUNNING_UNDER_MDM"))
-        {
-            if (nolock_reason != NULL)
-            {
+        if (getenv("RUNNING_UNDER_MDM")) {
+            if (nolock_reason != NULL) {
                 *nolock_reason = g_strdup("running under MDM");
             }
 
@@ -557,10 +530,8 @@ static gboolean lock_initialization (int       *argc,
                 macos = TRUE;
             #endif /* __APPLE__ */
 
-            if (macos)
-            {
-                if (nolock_reason != NULL)
-                {
+            if (macos) {
+                if (nolock_reason != NULL) {
                     *nolock_reason = g_strdup("Cannot lock securely on MacOS X");
                 }
 
@@ -574,8 +545,7 @@ static gboolean lock_initialization (int       *argc,
 }
 
 int main(int    argc,
-         char **argv)
-{
+         char **argv) {
     GError *error = NULL;
     char   *nolock_reason = NULL;
 
@@ -589,18 +559,15 @@ int main(int    argc,
 
     gs_profile_start(NULL);
 
-    if (!privileged_initialization(&argc, argv, verbose))
-    {
+    if (!privileged_initialization(&argc, argv, verbose)) {
         response_lock_init_failed();
         exit(1);
     }
 
     error = NULL;
 
-    if (!gtk_init_with_args(&argc, &argv, NULL, entries, NULL, &error))
-    {
-        if (error != NULL)
-        {
+    if (!gtk_init_with_args(&argc, &argv, NULL, entries, NULL, &error)) {
+        if (error != NULL) {
             fprintf(stderr, "%s", error->message);
             g_error_free(error);
         }
@@ -608,24 +575,20 @@ int main(int    argc,
         exit(1);
     }
 
-    if (!xfconf_init(&error))
-    {
+    if (!xfconf_init(&error)) {
         g_error("Failed to connect to xfconf daemon: %s.", error->message);
         g_error_free(error);
 
         exit(1);
     }
 
-    if (show_version)
-    {
+    if (show_version) {
         g_print("%s %s\n", argv[0], VERSION);
         exit(1);
     }
 
-    if (!lock_initialization(&argc, argv, &nolock_reason, verbose))
-    {
-        if (nolock_reason != NULL)
-        {
+    if (!lock_initialization(&argc, argv, &nolock_reason, verbose)) {
+        if (nolock_reason != NULL) {
             g_debug ("Screen locking disabled: %s", nolock_reason);
             g_free (nolock_reason);
         }
